@@ -4,6 +4,7 @@ from pathlib import Path
 import subprocess
 
 from ffmpeg import probe
+from tqdm import tqdm
 
 
 class FfmpegProcess:
@@ -13,7 +14,7 @@ class FfmpegProcess:
         Accepts an optional ffmpeg_loglevel parameter to set the value of FFmpeg's -loglevel argument.
         """
         self._command = command
-        self._ffmpeg_args = command + ["-progress", "pipe:1", "-nostats", "-loglevel", ffmpeg_loglevel]
+        self._ffmpeg_args = command + ["-progress", "-", "-nostats", "-loglevel", ffmpeg_loglevel]
 
     def run(self, progress_handler=None, ffmpeg_output_file=None):
         """
@@ -49,6 +50,7 @@ class FfmpegProcess:
         ffmpeg_stderr = ""
 
         print("Running FFmpeg...")
+        print('bla')
 
         with open(ffmpeg_output_file, "a") as f:
             self._process = subprocess.Popen(
@@ -57,39 +59,30 @@ class FfmpegProcess:
                 stderr=f,
             )
 
+        progress_bar = tqdm(
+            total=total_frames,
+            unit=" frames",
+            dynamic_ncols=True
+        )
+
+        progress_bar.clear()
+        previous_frame_number = 0
+
         try:
-            while self._process.poll() is None:           
-                ffmpeg_output = self._process.stdout.readline().decode("utf-8").strip()
-
-                if ffmpeg_output is not None:
-                    if can_get_duration:
-                        if "out_time_ms" in ffmpeg_output:
-                            microseconds = int(ffmpeg_output[12:])
-                            secs = microseconds / 1_000_000
-                            if file_duration is not None:
-                                percentage = round((secs / file_duration) * 100, 1)
-
-                        elif "speed" in ffmpeg_output:
-                            speed = ffmpeg_output.split("=")[1].strip()
-                            speed = 0 if " " in speed or "N/A" in speed else float(speed[:-1])
-                            if speed != 0:
-                                eta = (file_duration - secs) / speed
-                                minutes = int(eta / 60)
-                                seconds = round(eta % 60)
-                                eta_string = f"{minutes}m {seconds}s"
-
-                            if progress_handler is None:
-                                print(f"Progress: {percentage}% | Speed: {speed}x | ETA: {eta_string}", end="\r")
-                            else:
-                                progress_handler(percentage, f"{speed}x", eta)
-                    # ffprobe was unable to get the duration of the input file.
-                    else:
-                        print(self._process.stderr.readline().decode().strip())
-
-            width, height = os.get_terminal_size()
-            print("\r" + " " * (width - 1) + "\r", end="")
-            print("FFmpeg process complete.")
-
+            while self._process.poll() is None:
+                line = self._process.stdout.readline().decode("utf-8")
+                if "frame=" in line:
+                    frame_number = int(line[6:])
+                    frame_number_increase = frame_number - previous_frame_number
+                    progress_bar.update(frame_number_increase)
+                    previous_frame_number = frame_number
         except KeyboardInterrupt:
+            progress_bar.close()
             self._process.kill()
-            print("\nFFmpeg process killed.")
+            log.info("[KeyboardInterrupt] FFmpeg process killed. Exiting Video Quality Metrics.")
+            sys.exit(0)
+
+            # width, height = os.get_terminal_size()
+            # print("\r" + " " * (width - 1) + "\r", end="")
+            # print("FFmpeg process complete.")
+
